# pants-docker-generator

Pure Python Dockerfile generation for Pants plugins.

Provides `DockerConfig`, `HealthCheckConfig`, `generate_dockerfile`, and `generate_dockerignore` for building SLS-style Docker images.
